==> login_popup-2.0.0.zip: login_popup/src/Plugin/Block/LoginAndRegisterPopup.php <==
<?php

namespace Drupal\login_popup\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Link;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Render\Renderer;
use Drupal\Core\Session\AccountProxy;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'LoginAndRegisterPopup' block.
 *
 * @Block(
 *  id = "login_register_form_popup",
 *  admin_label = @Translation("Login and Registration Form Popup"),
 * )
 */
class LoginAndRegisterPopup extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The form_builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * The current_user service.
   *
   * @var \Drupal\Core\Session\AccountProxy
   */
  protected $currentUser;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\Renderer
   */
  protected $renderer;

  /**
   * Constructs a new WelcomeUserNameBlock.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form_builder service.
   * @param \Drupal\Core\Session\AccountProxy $currentUser
   *   The current_user service.
   * @param \Drupal\Core\Render\Renderer $renderer
   *   The renderer service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, FormBuilderInterface $form_builder, AccountProxy $currentUser, Renderer $renderer) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formBuilder = $form_builder;
    $this->currentUser = $currentUser;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('form_builder'),
      $container->get('current_user'),
      $container->get('renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $url_register = Url::fromRoute('user.register');
    $url_login = Url::fromRoute('user.login');
    $link_options = [
      'attributes' => [
        'class' => [
          'use-ajax',
          'login-popup-form',
        ],
        'data-dialog-type' => 'modal',
      ],
    ];
    $url_register->setOptions($link_options);
    $url_login->setOptions($link_options);
    $link_register = Link::fromTextAndUrl($this->t('Register'), $url_register)->toString();
    $link_login = Link::fromTextAndUrl($this->t('Log in'), $url_login)->toString();
    $build = [];
    if ($this->currentUser->isAnonymous()) {
      $build['login_register_popup_block']['#markup'] = '<div class="Login-Register-popup-link"><span>' . $link_login . '</span> | <span>' . $link_register . '</span></div>';
    }
    $build['login_register_popup_block']['#attached']['library'][] = 'core/drupal.dialog.ajax';

    return $build;
  }

}

==> login_popup-2.1.0.zip: login_popup/src/Plugin/Block/LoginAndRegisterPopup.php <==
<?php

namespace Drupal\login_popup\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Render\Renderer;
use Drupal\Core\Session\AccountProxy;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides a 'LoginAndRegisterPopup' block.
 *
 * @Block(
 *  id = "login_register_form_popup",
 *  admin_label = @Translation("Login and Registration Form Popup"),
 * )
 */
class LoginAndRegisterPopup extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The form_builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * The current_user service.
   *
   * @var \Drupal\Core\Session\AccountProxy
   */
  protected $currentUser;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\Renderer
   */
  protected $renderer;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Constructs a new WelcomeUserNameBlock.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form_builder service.
   * @param \Drupal\Core\Session\AccountProxy $currentUser
   *   The current_user service.
   * @param \Drupal\Core\Render\Renderer $renderer
   *   The renderer service.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, FormBuilderInterface $form_builder, AccountProxy $currentUser, Renderer $renderer, RequestStack $request_stack) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formBuilder = $form_builder;
    $this->currentUser = $currentUser;
    $this->renderer = $renderer;
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('form_builder'),
      $container->get('current_user'),
      $container->get('renderer'),
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return ['show_logout_link' => FALSE];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();
    $form['show_logout_link'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show Logout Link'),
      '#default_value' => !empty($config['show_logout_link']) ? $config['show_logout_link'] : FALSE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->setConfigurationValue('show_logout_link', $form_state->getValue('show_logout_link'));
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $base_url = $this->requestStack->getCurrentRequest()->getSchemeAndHttpHost();
    $url_register = Url::fromRoute('user.register');
    $url_login = Url::fromRoute('user.login');
    $config = $this->getConfiguration();
    $link_options = [
      'attributes' => [
        'class' => [
          'use-ajax',
          'login-popup-form',
        ],
        'data-dialog-type' => 'modal',
      ],
    ];
    $url_register->setOptions($link_options);
    $url_login->setOptions($link_options);
    $link_register = Link::fromTextAndUrl($this->t('Register'), $url_register)->toString();
    $link_login = Link::fromTextAndUrl($this->t('Log in'), $url_login)->toString();
    $build = [];
    if ($this->currentUser->isAnonymous()) {
      $build['login_register_popup_block']['#markup'] = '<div class="Login-Register-popup-link"><span>' . $link_login . '</span> | <span>' . $link_register . '</span></div>';
    }
    else {
      if ($config['show_logout_link']) {
        $build['login_register_popup_block']['#markup'] = '<div class="Login-Register-popup-link"><span><a href=" ' . $base_url . '/user/logout">Log out</a></div>';
      }
    }
    $build['login_register_popup_block']['#attached']['library'][] = 'core/drupal.dialog.ajax';

    return $build;
  }

}
